import _extends from '@babel/runtime/helpers/extends';
import _inheritsLoose from '@babel/runtime/helpers/inheritsLoose';
import _assertThisInitialized from '@babel/runtime/helpers/assertThisInitialized';
import React from 'react';
import PropTypes from 'prop-types';
import { utils, ComponentManager, ActionForwarder, AppContainer, AppContainerContext } from 'fractal-component';
import jss from 'jss';
import jssDefaultPreset from 'jss-preset-default';
import color from 'color';

var CLICK =
/*#__PURE__*/
Symbol("CLICK");

var actionTypes = /*#__PURE__*/Object.freeze({
    CLICK: CLICK
});

function click() {
  return {
    type: CLICK
  };
}

var index = /*#__PURE__*/Object.freeze({
    click: click
});

var styles = {
  table: {
    display: "flex",
    "flex-wrap": "wrap",
    margin: "0.2em 0.2em 0.2em 0.2em",
    padding: 0,
    "flex-direction": "column",
    width: "20em"
  },
  cell: {
    "box-sizing": "border-box",
    "flex-grow": 1,
    width: "100%",
    overflow: "hidden",
    padding: "0.2em 0.2em",
    border: "solid 2px " +
    /*#__PURE__*/
    color("slategrey").fade(0.5),
    "border-bottom": "none",
    "background-color": "#f7f7f7",
    display: "flex",
    "align-items": "center",
    "justify-content": "center",
    "&:last-child": {
      "border-bottom": "solid 2px " +
      /*#__PURE__*/
      color("slategrey").fade(0.5) + " !important"
    },
    "&$button-container": {
      height: "16.5em",
      "& button": {
        "font-size": "32px"
      },
      "& $active": {
        "background-color": "green",
        color: "white"
      },
      "& $inactive": {
        "background-color": "red",
        color: "white"
      }
    }
  },
  "button-container": {},
  active: {},
  inactive: {}
};

var is = utils.is;

var ToggleButton =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(ToggleButton, _React$Component);

  function ToggleButton(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.state = {
      isActive: false
    };
    _this.componentManager = new ComponentManager(_assertThisInitialized(_assertThisInitialized(_this)), {
      namespace: "io.github.t83714/ToggleButton",
      reducer: function reducer(state, action) {
        switch (action.type) {
          case CLICK:
            return _extends({}, state, {
              isActive: !state.isActive
            });

          default:
            return state;
        }
      },

      /**
       * Register actions for action serialisation / deserialisation.
       * It's much easier to use Symbol as action type to make sure no action type collision among different component.
       * ( Considering we now use actions as primary way for inter-component communication, it's quite important in a multicaset action environment)
       */
      actionTypes: actionTypes,
      // --- specify accepted types of external multicast actions
      // --- By default, component will not accept any incoming multicast action.
      // --- No limit to actions that are sent out
      allowedIncomingMulticastActionTypes: "*",
      namespaceInitCallback: function namespaceInitCallback(componentManager) {
        var jssRef;

        if (!props.styles) {
          // --- if use built-in style, we want to make sure this component use its own jss setting
          jssRef = jss.setup(jssDefaultPreset());
        } else {
          jssRef = jss;
        }

        var styleSheet = jssRef.createStyleSheet(props.styles ? props.styles : styles, {
          generateClassName: componentManager.createClassNameGenerator()
        }).attach();
        return {
          styleSheet: styleSheet
        };
      },
      namespaceDestroyCallback: function namespaceDestroyCallback(_ref) {
        var styleSheet = _ref.styleSheet;
        styleSheet.detach();
      }
    });
    return _this;
  }

  var _proto = ToggleButton.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$componentManage = this.componentManager.getNamespaceData(),
        styleSheet = _this$componentManage.styleSheet;

    var classes = styleSheet.classes;
    return React.createElement("div", {
      className: classes.table
    }, React.createElement("div", {
      className: classes.cell
    }, "ToggleButton"), React.createElement("div", {
      className: classes.cell + " " + classes["button-container"]
    }, React.createElement("button", {
      className: this.state.isActive ? classes["active"] : classes["inactive"],
      onClick: function onClick() {
        _this2.componentManager.dispatch(click());
      }
    }, this.state.isActive ? "ACTIVE" : "INACTIVE")), React.createElement(ActionForwarder, {
      namespacePrefix: this.props.namespacePrefix,
      pattern: this.props.pattern,
      relativeDispatchPath: this.props.relativeDispatchPath,
      transformer: function transformer(action) {
        var newAction;

        if (is.func(_this2.props.transformer)) {
          newAction = _this2.props.transformer(action);
        } else if (is.symbol(_this2.props.transformer)) {
          newAction = _extends({}, action, {
            type: _this2.props.transformer
          });
        } else {
          throw new Error("Invalid transformer type.");
        }

        return _extends({}, newAction, {
          toggleButtonActive: _this2.state.isActive
        });
      },
      appContainer: this.props.appContainer
    }));
  };

  return ToggleButton;
}(React.Component);

ToggleButton.propTypes = {
  namespacePrefix: PropTypes.string.isRequired,
  pattern:
  /*#__PURE__*/
  PropTypes.oneOfType([PropTypes.symbol, PropTypes.func,
  /*#__PURE__*/
  PropTypes.arrayOf(
  /*#__PURE__*/
  PropTypes.oneOfType([PropTypes.string, PropTypes.func]))]),
  relativeDispatchPath: PropTypes.string,
  transformer:
  /*#__PURE__*/
  PropTypes.oneOfType([PropTypes.symbol, PropTypes.func]),
  styles: PropTypes.object,
  appContainer:
  /*#__PURE__*/
  PropTypes.instanceOf(AppContainer)
}; // --- Define contentType allow `AppContainer` pass through React Content

ToggleButton.contextType = AppContainerContext;

export default ToggleButton;
export { actionTypes, index as actions };
//# sourceMappingURL=toggle-button.esm.js.map
